@@ -1,6 +1,6 @@
 use tombi_future::{BoxFuture, Boxable};
 use tombi_schema_store::{
-    AllOfSchema, AnyOfSchema, OneOfSchema, PropertySchema, SchemaAccessor, ValueSchema,
+    Accessor, AllOfSchema, AnyOfSchema, OneOfSchema, PropertySchema, SchemaAccessor, ValueSchema,
 };
 use tombi_validator::Validate;
 
@@ -15,7 +15,7 @@ mod value;
 pub trait Edit {
     fn edit<'a: 'b, 'b>(
         &'a self,
-        accessors: &'a [tombi_schema_store::SchemaAccessor],
+        accessors: &'a [tombi_schema_store::Accessor],
         source_path: Option<&'a std::path::Path>,
         current_schema: Option<&'a tombi_schema_store::CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext<'a>,
@@ -24,14 +24,13 @@ pub trait Edit {
 
 async fn get_schema<'a: 'b, 'b>(
     value: &'a tombi_document_tree::Value,
-    accessors: &'a [tombi_schema_store::SchemaAccessor],
+    accessors: &'a [tombi_schema_store::Accessor],
     current_schema: &'a tombi_schema_store::CurrentSchema<'a>,
     schema_context: &'a tombi_schema_store::SchemaContext<'a>,
 ) -> Option<ValueSchema> {
     fn inner_get_schema<'a: 'b, 'b>(
         value: &'a tombi_document_tree::Value,
-        accessors: &'a [tombi_schema_store::SchemaAccessor],
-        validation_accessors: &'a [tombi_schema_store::SchemaAccessor],
+        accessors: &'a [tombi_schema_store::Accessor],
         current_schema: &'a tombi_schema_store::CurrentSchema<'a>,
         schema_context: &'a tombi_schema_store::SchemaContext<'a>,
     ) -> BoxFuture<'b, Option<ValueSchema>> {
@@ -49,15 +48,11 @@ async fn get_schema<'a: 'b, 'b>(
                                 schema_context.store,
                             )
                             .await
+                            .inspect_err(|err| tracing::warn!("{err}"))
                         {
-                            if let Some(value_schema) = inner_get_schema(
-                                value,
-                                accessors,
-                                validation_accessors,
-                                &current_schema,
-                                schema_context,
-                            )
-                            .await
+                            if let Some(value_schema) =
+                                inner_get_schema(value, accessors, &current_schema, schema_context)
+                                    .await
                             {
                                 return Some(value_schema);
                             }
@@ -71,14 +66,14 @@ async fn get_schema<'a: 'b, 'b>(
 
             if accessors.is_empty() {
                 return value
-                    .validate(validation_accessors, Some(current_schema), schema_context)
+                    .validate(accessors, Some(current_schema), schema_context)
                     .await
                     .ok()
                     .map(|_| current_schema.value_schema.as_ref().clone());
             }
 
             match &accessors[0] {
-                SchemaAccessor::Key(key) => {
+                Accessor::Key(key) => {
                     if let (
                         tombi_document_tree::Value::Table(table),
                         ValueSchema::Table(table_schema),
@@ -100,11 +95,11 @@ async fn get_schema<'a: 'b, 'b>(
                                         schema_context.store,
                                     )
                                     .await
+                                    .inspect_err(|err| tracing::warn!("{err}"))
                                 {
                                     return inner_get_schema(
                                         value,
                                         &accessors[1..],
-                                        validation_accessors,
                                         &current_schema,
                                         schema_context,
                                     )
@@ -128,11 +123,11 @@ async fn get_schema<'a: 'b, 'b>(
                                                     schema_context.store,
                                                 )
                                                 .await
+                                                .inspect_err(|err| tracing::warn!("{err}"))
                                             {
                                                 return inner_get_schema(
                                                     value,
                                                     &accessors[1..],
-                                                    validation_accessors,
                                                     &current_schema,
                                                     schema_context,
                                                 )
@@ -140,7 +135,7 @@ async fn get_schema<'a: 'b, 'b>(
                                             }
                                         }
                                     } else {
-                                        tracing::error!(
+                                        tracing::warn!(
                                             "Invalid regex pattern property: {}",
                                             property_key
                                         );
@@ -159,11 +154,11 @@ async fn get_schema<'a: 'b, 'b>(
                                         schema_context.store,
                                     )
                                     .await
+                                    .inspect_err(|err| tracing::warn!("{err}"))
                                 {
                                     return inner_get_schema(
                                         value,
                                         &accessors[1..],
-                                        validation_accessors,
                                         &current_schema,
                                         schema_context,
                                     )
@@ -173,7 +168,7 @@ async fn get_schema<'a: 'b, 'b>(
                         }
                     }
                 }
-                SchemaAccessor::Index => {
+                Accessor::Index(_) => {
                     if let (
                         tombi_document_tree::Value::Array(array),
                         ValueSchema::Array(array_schema),
@@ -192,11 +187,11 @@ async fn get_schema<'a: 'b, 'b>(
                                         schema_context.store,
                                     )
                                     .await
+                                    .inspect_err(|err| tracing::warn!("{err}"))
                                 {
                                     return inner_get_schema(
                                         value,
                                         &accessors[1..],
-                                        validation_accessors,
                                         &current_schema,
                                         schema_context,
                                     )
@@ -215,5 +210,5 @@ async fn get_schema<'a: 'b, 'b>(
         .boxed()
     }
 
-    inner_get_schema(value, accessors, accessors, current_schema, schema_context).await
+    inner_get_schema(value, accessors, current_schema, schema_context).await
 }
