@@ -1,4 +1,6 @@
 use itertools::Itertools;
+use tombi_comment_directive::value::{TableCommonLintRules, TableFormatRules};
+use tombi_comment_directive_serde::get_comment_directive_content;
 use tombi_future::{BoxFuture, Boxable};
 use tombi_syntax::SyntaxElement;
 
@@ -8,7 +10,7 @@ use tombi_ast::AstToken;
 impl crate::Edit for tombi_ast::Root {
     fn edit<'a: 'b, 'b>(
         &'a self,
-        _accessors: &'a [tombi_schema_store::SchemaAccessor],
+        _accessors: &'a [tombi_schema_store::Accessor],
         source_path: Option<&'a std::path::Path>,
         current_schema: Option<&'a tombi_schema_store::CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext<'a>,
@@ -18,11 +20,16 @@ impl crate::Edit for tombi_ast::Root {
             let mut key_values = vec![];
             let mut table_or_array_of_tables = vec![];
 
+            let comment_directive = get_comment_directive_content::<
+                TableFormatRules,
+                TableCommonLintRules,
+            >(self.comment_directives());
+
             // Move document schema/tombi comment directive to the top.
             if self
-                .document_schema_comment_directive(source_path)
+                .schema_document_comment_directive(source_path)
                 .is_some()
-                || self.document_tombi_comment_directives().is_some()
+                || !self.tombi_document_comment_directives().is_empty()
             {
                 changes.push(crate::Change::AppendTop {
                     new: self
@@ -69,6 +76,7 @@ impl crate::Edit for tombi_ast::Root {
                     table_or_array_of_tables,
                     current_schema,
                     schema_context,
+                    comment_directive,
                 )
                 .await,
             );
