@@ -10,7 +10,7 @@ pub async fn get_tombi_cache_dir_path() -> Option<std::path::PathBuf> {
 
         if !cache_dir_path.is_dir() {
             if let Err(error) = tokio::fs::create_dir_all(&cache_dir_path).await {
-                tracing::error!("Failed to create cache directory: {error}");
+                tracing::warn!("Failed to create cache directory: {error}");
                 return None;
             }
         }
@@ -23,7 +23,7 @@ pub async fn get_tombi_cache_dir_path() -> Option<std::path::PathBuf> {
         cache_dir_path.push("tombi");
         if !cache_dir_path.is_dir() {
             if let Err(error) = std::fs::create_dir_all(&cache_dir_path) {
-                tracing::error!("Failed to create cache directory: {error}");
+                tracing::warn!("Failed to create cache directory: {error}");
                 return None;
             }
         }
