@@ -11,10 +11,11 @@ pub use error::Error;
 pub use files::FilesOptions;
 pub use format::FormatOptions;
 pub use level::ConfigLevel;
-pub use lint::{LintOptions, SeverityLevel};
+pub use lint::LintOptions;
 pub use schema::SchemaOptions;
 pub use schema::{RootSchema, Schema, SubSchema};
 pub use server::{LspCompletion, LspOptions};
+pub use tombi_severity_level::SeverityLevel;
 pub use tombi_toml_version::TomlVersion;
 pub use types::*;
 
@@ -37,41 +38,50 @@ pub const TOMBI_CONFIG_TOML_VERSION: TomlVersion = TomlVersion::V1_1_0_Preview;
 #[cfg_attr(feature = "jsonschema", schemars(extend("x-tombi-table-keys-order" = tombi_x_keyword::TableKeysOrder::Schema)))]
 #[cfg_attr(feature = "jsonschema", schemars(extend("$id" = "https://json.schemastore.org/tombi.json")))]
 pub struct Config {
-    /// # TOML version.
+    /// # TOML version
     ///
     /// TOML version to use if not specified in the schema and comment directive.
     #[cfg_attr(feature = "jsonschema", schemars(default = "TomlVersion::default"))]
     pub toml_version: Option<TomlVersion>,
 
-    /// # Deprecated. Use `files.include` instead.
+    /// # File patterns to include
+    ///
+    /// **🚧 Deprecated 🚧**\
+    /// Please use `files.include` instead.
     #[cfg_attr(feature = "jsonschema", deprecated)]
     #[cfg_attr(feature = "jsonschema", schemars(length(min = 1)))]
     include: Option<Vec<String>>,
 
-    /// # Deprecated. Use `files.exclude` instead.
+    /// # File patterns to exclude
+    ///
+    /// **🚧 Deprecated 🚧**\
+    /// Please use `files.exclude` instead.
     #[cfg_attr(feature = "jsonschema", deprecated)]
     #[cfg_attr(feature = "jsonschema", schemars(length(min = 1)))]
     exclude: Option<Vec<String>>,
 
     pub files: Option<FilesOptions>,
 
-    /// # Formatter options.
+    /// # Formatter options
     pub format: Option<FormatOptions>,
 
-    /// # Linter options.
+    /// # Linter options
     pub lint: Option<LintOptions>,
 
-    /// # Language Server Protocol options.
+    /// # Language Server options
     lsp: Option<LspOptions>,
 
-    /// # Deprecated. Use `lsp` instead.
+    /// # Language Server options
+    ///
+    /// **🚧 Deprecated 🚧**\
+    /// Please use `lsp` instead.
     #[cfg_attr(feature = "jsonschema", deprecated)]
     server: Option<LspOptions>,
 
-    /// # Schema options.
+    /// # Schema options
     pub schema: Option<SchemaOptions>,
 
-    /// # Schema catalog items.
+    /// # Schema catalog items
     pub schemas: Option<Vec<Schema>>,
 }
 
