@@ -2,7 +2,7 @@ use ahash::AHashSet;
 use itertools::Itertools;
 use std::borrow::Cow;
 use tombi_document_tree::{ArrayKind, LiteralValueRef};
-use tombi_extension::CompletionKind;
+use tombi_extension::{AddLeadingComma, AddTrailingComma, CompletionKind};
 use tombi_future::Boxable;
 use tombi_schema_store::{
     Accessor, ArraySchema, CurrentSchema, DocumentSchema, SchemaUri, ValueSchema,
@@ -12,7 +12,13 @@ use super::{
     all_of::find_all_of_completion_items, any_of::find_any_of_completion_items,
     one_of::find_one_of_completion_items, type_hint_value, CompletionHint, FindCompletionContents,
 };
-use crate::completion::{schema_completion::SchemaCompletion, CompletionContent, CompletionEdit};
+use crate::{
+    comment_directive::get_array_comment_directive_content_with_schema_uri,
+    completion::{
+        comment::get_tombi_comment_directive_content_completion_contents,
+        schema_completion::SchemaCompletion, CompletionContent, CompletionEdit,
+    },
+};
 
 impl FindCompletionContents for tombi_document_tree::Array {
     fn find_completion_contents<'a: 'b, 'b>(
@@ -31,6 +37,22 @@ impl FindCompletionContents for tombi_document_tree::Array {
         tracing::trace!("completion_hint = {:?}", completion_hint);
 
         async move {
+            if keys.is_empty() {
+                if let Some((comment_directive_context, schema_uri)) =
+                    get_array_comment_directive_content_with_schema_uri(self, position, accessors)
+                {
+                    if let Some(completions) =
+                        get_tombi_comment_directive_content_completion_contents(
+                            comment_directive_context,
+                            schema_uri,
+                        )
+                        .await
+                    {
+                        return completions;
+                    }
+                }
+            }
+
             if let Some(Ok(DocumentSchema {
                 value_schema: Some(value_schema),
                 schema_uri,
@@ -60,11 +82,13 @@ impl FindCompletionContents for tombi_document_tree::Array {
                 match current_schema.value_schema.as_ref() {
                     ValueSchema::Array(array_schema) => {
                         let mut new_item_index = 0;
+                        let mut new_item_start_position = None;
                         for (index, value) in self.values().iter().enumerate() {
                             if value.range().end < position {
                                 new_item_index = index + 1;
+                                new_item_start_position = Some(value.range().end);
                             }
-                            if value.range().contains(position) {
+                            if value.contains(position) {
                                 let accessor = Accessor::Index(index);
                                 if let Some(items) = &array_schema.items {
                                     if let Ok(Some(current_schema)) = items
@@ -95,6 +119,7 @@ impl FindCompletionContents for tombi_document_tree::Array {
                                 }
                             }
                         }
+
                         if let Some(items) = &array_schema.items {
                             if let Ok(Some(current_schema)) = items
                                 .write()
@@ -118,7 +143,62 @@ impl FindCompletionContents for tombi_document_tree::Array {
                                         Some(&current_schema),
                                         schema_context,
                                         if self.kind() == ArrayKind::Array {
-                                            Some(CompletionHint::InArray)
+                                            if new_item_index == 0 {
+                                                let add_trailing_comma = if self.len() == 0
+                                                    || matches!(
+                                                        completion_hint,
+                                                        Some(CompletionHint::Comma {
+                                                            trailing_comma: Some(_),
+                                                            ..
+                                                        })
+                                                    ) {
+                                                    None
+                                                } else {
+                                                    Some(AddTrailingComma)
+                                                };
+
+                                                Some(CompletionHint::InArray {
+                                                    add_leading_comma: None,
+                                                    add_trailing_comma,
+                                                })
+                                            } else {
+                                                let add_leading_comma = if matches!(
+                                                    completion_hint,
+                                                    Some(CompletionHint::Comma {
+                                                        leading_comma: Some(_),
+                                                        ..
+                                                    })
+                                                ) {
+                                                    None
+                                                } else if let Some(start_position) =
+                                                    new_item_start_position
+                                                {
+                                                    Some(AddLeadingComma { start_position })
+                                                } else {
+                                                    None
+                                                };
+
+                                                let add_trailing_comma = if matches!(
+                                                    completion_hint,
+                                                    Some(CompletionHint::Comma {
+                                                        trailing_comma: Some(_),
+                                                        ..
+                                                    })
+                                                ) {
+                                                    None
+                                                } else {
+                                                    if new_item_index != self.len() {
+                                                        Some(AddTrailingComma)
+                                                    } else {
+                                                        None
+                                                    }
+                                                };
+
+                                                Some(CompletionHint::InArray {
+                                                    add_leading_comma,
+                                                    add_trailing_comma,
+                                                })
+                                            }
                                         } else {
                                             completion_hint
                                         },
@@ -126,7 +206,7 @@ impl FindCompletionContents for tombi_document_tree::Array {
                                     .await;
 
                                 if array_schema.unique_items == Some(true) {
-                                    let values = self
+                                    let unique_values = self
                                         .values()
                                         .iter()
                                         .filter_map(Option::<LiteralValueRef>::from)
@@ -137,7 +217,7 @@ impl FindCompletionContents for tombi_document_tree::Array {
                                         .into_iter()
                                         .filter(|completion| {
                                             !(completion.kind.is_literal()
-                                                && values.contains(&completion.label))
+                                                && unique_values.contains(&completion.label))
                                         })
                                         .collect_vec();
                                 }
@@ -191,17 +271,21 @@ impl FindCompletionContents for tombi_document_tree::Array {
                 }
             } else {
                 for (index, value) in self.values().iter().enumerate() {
-                    if value.range().contains(position) {
+                    if value.contains(position) {
+                        // Array of tables
                         if let tombi_document_tree::Value::Table(table) = value {
                             if keys.len() == 1
                                 && table.kind() == tombi_document_tree::TableKind::KeyValue
                             {
                                 let key = &keys.first().unwrap();
                                 return vec![CompletionContent::new_type_hint_key(
-                                    &key.to_raw_text(schema_context.toml_version),
+                                    &key.value,
                                     key.range(),
                                     None,
-                                    Some(CompletionHint::InArray),
+                                    Some(CompletionHint::InArray {
+                                        add_leading_comma: None,
+                                        add_trailing_comma: None,
+                                    }),
                                 )];
                             }
                         }
@@ -215,7 +299,7 @@ impl FindCompletionContents for tombi_document_tree::Array {
                                     .iter()
                                     .cloned()
                                     .chain(std::iter::once(accessor))
-                                    .collect::<Vec<_>>(),
+                                    .collect_vec(),
                                 None,
                                 schema_context,
                                 completion_hint,
@@ -223,13 +307,7 @@ impl FindCompletionContents for tombi_document_tree::Array {
                             .await;
                     }
                 }
-                type_hint_value(
-                    None,
-                    position,
-                    schema_context.toml_version,
-                    None,
-                    completion_hint,
-                )
+                type_hint_value(None, position, None, completion_hint)
             }
         }
         .boxed()
@@ -240,12 +318,19 @@ impl FindCompletionContents for ArraySchema {
     fn find_completion_contents<'a: 'b, 'b>(
         &'a self,
         position: tombi_text::Position,
-        _keys: &'a [tombi_document_tree::Key],
-        _accessors: &'a [Accessor],
+        keys: &'a [tombi_document_tree::Key],
+        accessors: &'a [Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         _schema_context: &'a tombi_schema_store::SchemaContext<'a>,
         completion_hint: Option<CompletionHint>,
     ) -> tombi_future::BoxFuture<'b, Vec<CompletionContent>> {
+        tracing::trace!("self = {:?}", self);
+        tracing::trace!("position = {:?}", position);
+        tracing::trace!("keys = {:?}", keys);
+        tracing::trace!("accessors = {:?}", accessors);
+        tracing::trace!("current_schema = {:?}", current_schema);
+        tracing::trace!("completion_hint = {:?}", completion_hint);
+
         async move {
             match completion_hint {
                 Some(CompletionHint::InTableHeader) => Vec::with_capacity(0),
