@@ -1,6 +1,7 @@
 use itertools::Either;
-use tombi_ast::DocumentSchemaCommentDirective;
+use tombi_ast::SchemaDocumentCommentDirective;
 use tombi_document_tree::IntoDocumentTreeAndErrors;
+use tombi_extension::get_tombi_github_uri;
 use tower_lsp::lsp_types::{DocumentLink, DocumentLinkParams};
 
 use crate::{config_manager::ConfigSchemaStore, Backend};
@@ -41,17 +42,17 @@ pub async fn handle_document_link(
 
     let mut document_links = vec![];
 
-    if let Some(DocumentSchemaCommentDirective {
+    if let Some(SchemaDocumentCommentDirective {
         uri: Ok(schema_uri),
         uri_range: range,
         ..
-    }) = root.document_schema_comment_directive(text_document_uri.to_file_path().ok().as_deref())
+    }) = root.schema_document_comment_directive(text_document_uri.to_file_path().ok().as_deref())
     {
         let tooltip = "Open JSON Schema".into();
         document_links.push(
             tombi_extension::DocumentLink {
                 range,
-                target: schema_uri,
+                target: get_tombi_github_uri(&schema_uri).unwrap_or(schema_uri.into()),
                 tooltip,
             }
             .into(),
@@ -65,11 +66,11 @@ pub async fn handle_document_link(
         .ok()
         .flatten();
 
-    let document_tombi_comment_directive =
-        tombi_comment_directive::get_document_tombi_comment_directive(&root).await;
+    let tombi_document_comment_directive =
+        tombi_validator::comment_directive::get_tombi_document_comment_directive(&root).await;
     let (toml_version, _) = backend
         .source_toml_version(
-            document_tombi_comment_directive,
+            tombi_document_comment_directive,
             source_schema.as_ref(),
             &config,
         )
