@@ -1,12 +1,18 @@
+use tombi_comment_directive::value::{LocalTimeCommonLintRules, LocalTimeFormatRules};
 use tombi_schema_store::{Accessor, CurrentSchema, LocalTimeSchema, ValueSchema};
 
-use crate::hover::{
-    all_of::get_all_of_hover_content,
-    any_of::get_any_of_hover_content,
-    constraints::{build_enumerate_values, ValueConstraints},
-    display_value::DisplayValue,
-    one_of::get_one_of_hover_content,
-    GetHoverContent, HoverValueContent,
+use crate::{
+    comment_directive::get_key_table_value_comment_directive_content_and_schema_uri,
+    hover::{
+        all_of::get_all_of_hover_content,
+        any_of::get_any_of_hover_content,
+        comment::get_value_comment_directive_hover_content,
+        constraints::{build_enumerate_values, ValueConstraints},
+        display_value::DisplayValue,
+        one_of::get_one_of_hover_content,
+        GetHoverContent, HoverValueContent,
+    },
+    HoverContent,
 };
 use tombi_future::Boxable;
 
@@ -18,23 +24,43 @@ impl GetHoverContent for tombi_document_tree::LocalTime {
         accessors: &'a [Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>> {
+    ) -> tombi_future::BoxFuture<'b, Option<HoverContent>> {
         async move {
+            if let Some((comment_directive_context, schema_uri)) =
+                get_key_table_value_comment_directive_content_and_schema_uri::<
+                    LocalTimeFormatRules,
+                    LocalTimeCommonLintRules,
+                >(self.comment_directives(), position, accessors)
+            {
+                if let Some(hover_content) =
+                    get_value_comment_directive_hover_content(comment_directive_context, schema_uri)
+                        .await
+                {
+                    return Some(hover_content);
+                }
+            }
+
             if let Some(current_schema) = current_schema {
                 match current_schema.value_schema.as_ref() {
-                    ValueSchema::LocalTime(schema) => schema
-                        .get_hover_content(
-                            position,
-                            keys,
-                            accessors,
-                            Some(current_schema),
-                            schema_context,
-                        )
-                        .await
-                        .map(|mut hover_content| {
-                            hover_content.range = Some(self.range());
-                            hover_content
-                        }),
+                    ValueSchema::LocalTime(local_time_schema) => {
+                        let mut hover_content = local_time_schema
+                            .get_hover_content(
+                                position,
+                                keys,
+                                accessors,
+                                Some(current_schema),
+                                schema_context,
+                            )
+                            .await;
+
+                        if let Some(HoverContent::Value(hover_value_content)) =
+                            hover_content.as_mut()
+                        {
+                            hover_value_content.range = Some(self.range());
+                        }
+
+                        hover_content
+                    }
                     ValueSchema::OneOf(one_of_schema) => {
                         get_one_of_hover_content(
                             self,
@@ -77,15 +103,15 @@ impl GetHoverContent for tombi_document_tree::LocalTime {
                     _ => None,
                 }
             } else {
-                Some(HoverValueContent {
+                Some(HoverContent::Value(HoverValueContent {
                     title: None,
                     description: None,
-                    accessors: tombi_schema_store::Accessors::new(accessors.to_vec()),
+                    accessors: tombi_schema_store::Accessors::from(accessors.to_vec()),
                     value_type: tombi_schema_store::ValueType::LocalTime,
                     constraints: None,
                     schema_uri: None,
                     range: Some(self.range()),
-                })
+                }))
             }
         }
         .boxed()
@@ -100,12 +126,12 @@ impl GetHoverContent for LocalTimeSchema {
         accessors: &'a [Accessor],
         current_schema: Option<&'a CurrentSchema<'a>>,
         _schema_context: &'a tombi_schema_store::SchemaContext,
-    ) -> tombi_future::BoxFuture<'b, Option<HoverValueContent>> {
+    ) -> tombi_future::BoxFuture<'b, Option<HoverContent>> {
         async move {
-            Some(HoverValueContent {
+            Some(HoverContent::Value(HoverValueContent {
                 title: self.title.clone(),
                 description: self.description.clone(),
-                accessors: tombi_schema_store::Accessors::new(accessors.to_vec()),
+                accessors: tombi_schema_store::Accessors::from(accessors.to_vec()),
                 value_type: tombi_schema_store::ValueType::LocalTime,
                 constraints: Some(ValueConstraints {
                     enumerate: build_enumerate_values(
@@ -128,7 +154,7 @@ impl GetHoverContent for LocalTimeSchema {
                 schema_uri: current_schema
                     .map(|current_schema| current_schema.schema_uri.as_ref().clone()),
                 range: None,
-            })
+            }))
         }
         .boxed()
     }
