@@ -1,4 +1,4 @@
-use crate::SchemaUrl;
+use crate::SchemaUri;
 
 #[derive(Debug, Clone, serde::Deserialize)]
 #[serde(rename_all = "camelCase")]
@@ -7,5 +7,5 @@ pub struct JsonCatalogSchema {
     pub description: String,
     #[serde(default)]
     pub file_match: Vec<String>,
-    pub url: SchemaUrl,
+    pub url: SchemaUri,
 }
